# BSVARfit.R
#
# Analysis of macropolitical economy data using a BSVAR model.
#
# This file finds the posterior modes of the various models, which can
# then be used for sampling the posterior, IRFs, and DFEVs.
#
# Brandt and Freeman BVAR 2 paper -- AJPS
#
# Patrick Brandt
# pbrandt@utdallas.edu
#
######################################################################
# Begun: 8/5/2005
# Revised: 9/10/2005  -- New identification schemes.
#          9/21/2005  -- eval new version of the sampling of SVAR
#          11/9/2005  -- parallel version of the Gibbs sampler
#                     -- added election counter variables
#          11/10/2005 -- Added function to generate MCMC list chain
#                        object and summarization of the posterior of
#                        A(0) using coda pkg functions
#          11/30/2005 -- Changed A(0) to allow for the contemp effects
#                        of approval on MS and MD, per Williams (1990)
#          03/20/2006 -- Use new MSBVAR 0.1.10 and MLA normalization
#                        rule
#          04/18/2006 -- Updated to use latest MSBVAR 0.1.13 and moved
#                        functions and common code from this and other
#                        files into setupBVAR2.R
#          08/15/2006 -- Updated to work with MSBVAR 0.2.0 and to
#                        split analysis into separate files BSVAR*.R
#                        for fit, IRFs, and DFEVs
#          08/21/2006 -- Revised hyperparameters to match results of
#                        sensitivity analysis
#          09/11/2006 -- Updated hyperparameters
#          12/04/2007 -- Revised to use latest version of MSBVAR 0.3.0
######################################################################

# Load libraries
library(MSBVAR)  # Brandt BVAR / VAR library

# Load the data and other functions
load("Data_Setup.RData")

# Fit BSVAR models to the Macro Political Econ data

# Estimate the model's posterior moments
set.seed(273)

flatprior.model <- szbsvar(Y, p, z=X,
                           lambda0=1, lambda1=10, lambda3=0,
                           lambda4=10, lambda5=10,
                           mu5=0, mu6=0,
                           ident = general.A0,
                           qm)

running.tally.model <- szbsvar(Y, p, z=X,
                               lambda0=0.6, lambda1=0.1, lambda3=1,
                               lambda4=0.1, lambda5=0.07,
                               mu5=5, mu6=5,
                               ident = general.A0,
                               qm)

midrange.model <- szbsvar(Y, p, z=X,
                          lambda0=0.6, lambda1=0.15, lambda3=1,
                          lambda4=0.15, lambda5=0.07,
                          mu5=2, mu6=2,
                          ident = general.A0,
                          qm)


best.model <- szbsvar(Y, p, z=X,
                      lambda0=0.6, lambda1=0.2, lambda3=1,
                      lambda4=0.2, lambda5=0.07,
                      mu5=0, mu6=1,
                      ident = general.A0,
                      qm)

bestML.model <- szbsvar(Y, p, z=X,
                        lambda0=0.6, lambda1=0.2, lambda3=2,
                        lambda4=0.2, lambda5=0.07,
                        mu5=5, mu6=1,
                        ident = general.A0,
                        qm)


# Save results of models
save.image("BSVARfit.RData")
q(save="no")
